==> musescore-3.0.1.tar.gz: MuseScore-3.0.1/share/locale/tours_ko.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ko" version="2.1">
<context>
    <name>TourXML</name>
    <message>
        <source>To add a note to a chord, press Shift while typing its letter name, or click on the staff.</source>
        <comment>note-input</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Welcome to MuseScore! This brief tour will guide you through the MuseScore user interface.</source>
        <comment>welcome</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The Playback Controls toolbar allows you to play/pause your score and control various aspects of playback.</source>
        <comment>welcome</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The Note Input toolbar allows you to enter notes and rests into your score.</source>
        <comment>welcome</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The Palettes allow you to add most other notation elements to your score.</source>
        <comment>welcome</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Each palette contains items that can be added to the score.</source>
        <comment>show-palette</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Welcome to the Palettes, where you will add various elements to your score. Click &quot;Next&quot; to learn more.</source>
        <comment>show-palette</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>To enter a note of the selected duration, type its letter name or click on the staff.
    Press Ctrl+Up/Down (macOS: Cmd+Up/Down) to change octave.</source>
        <comment>note-input</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>To add an accidental to a note, press the shortcut Up or Down to raise or lower its pitch,
    or click one of these icons.</source>
        <comment>note-input</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>To enter notes with different rhythms in the same measure, use multiple voices.
    Each staff can have up to four voices.
    The default is voice 1, and it should be used first for each staff.
    To enter notes into a different voice, click one of these icons.</source>
        <comment>note-input</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>This is the score view, where you can view and edit your score.
    Use your mouse wheel or touchpad to scroll (with Shift to scroll horizontally).
    If you have multiple scores open, you can switch between them using tabs at the top of your score view.</source>
        <comment>welcome</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>These are the toolbars.
    The main three are File Operations, Playback Controls, and Note Input.</source>
        <comment>welcome</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The main menu contains most other commands.
    In addition, many commands can be accessed via keyboard shortcuts or by right-clicking (macOS: Ctrl+clicking) within the score view.</source>
        <comment>welcome</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>There are different workspaces available with different sets of palettes.
    The &quot;Advanced&quot; workspace contains more items than the &quot;Basic&quot; workspace.</source>
        <comment>show-palette</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>To add a palette item to your score, first select an element or range in your score, then double-click on the palette item to add it to the selected elements.
    You can also drag an item from the palette and drop it on a specific element in your score.</source>
        <comment>show-palette</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You have toggled multimeasure rests in this score.
    This combines multiple measures of rests into a single multimeasure rest.
    To toggle this setting again, press the shortcut &quot;M&quot;.</source>
        <comment>mmrest</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Welcome to note input, where you will enter notes and rests into your score.
    Click &quot;Next&quot; to learn more.</source>
        <comment>note-input</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>To enable note input mode, click the &quot;Note input&quot; icon or press the shortcut &quot;N&quot;.</source>
        <comment>note-input</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Select a duration by clicking one of these icons or pressing the shortcuts &quot;1&quot; - &quot;9&quot;.
    To include an augmentation dot, click the appropriate icon or press the shortcut &quot;.&quot;.</source>
        <comment>note-input</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>To enter a rest of the selected duration, press the shortcut &quot;0&quot;, or select this icon then click on the staff.</source>
        <comment>note-input</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>To extend a note by adding a tied note, select the duration to extend by, then press &quot;+&quot; or click this button.</source>
        <comment>note-input</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>MuseScore provides many ways to navigate through your score.
    Click &quot;Next&quot; to learn more.</source>
        <comment>navigate-tour</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The quickest way to scroll up and down is to use your mouse wheel or equivalent touch gesture (for example, two-finger swipe).
    To scroll horizontally, hold Shift while using the mouse wheel or touch gesture.</source>
        <comment>navigate-tour</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The navigation keys on your keyboard such as PgUp, PgDn, Home, and End function as in other applications
    to move between pages.
    Keyboards that lack these keys often provide equivalents such as Fn+Up/Down/Left/Right.</source>
        <comment>navigate-tour</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You can move the score short distances by clicking an empty area of the page and dragging.
    By the way, you can also select regions by holding Shift while dragging.</source>
        <comment>navigate-tour</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Additional navigation tools include the Timeline and Navigator, both found in the View menu.</source>
        <comment>navigate-tour</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Welcome to the Inspector, where you can change individual properties for selected elements.
    Click &quot;Next&quot; to learn more.</source>
        <comment>inspector-tour</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Begin by selecting one or more elements in your score, then use the check boxes, spin boxes, dropdown menus, and other controls to change values for the various properties.
    The set of properties available will differ according to the type of selected elements or elements.</source>
        <comment>inspector-tour</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>If you have selected elements of different types, only a few settings common to all elements will be available.
    You can click the &quot;Notes&quot; and other buttons at the bottom of the Inspector to limit the selection to just the elements of the specified type.</source>
        <comment>inspector-tour</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The Inspector allows you to control various properties of the elements in your score.</source>
        <comment>welcome</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Autoplace is a new feature that automatically detects and avoids many types of collisions between elements.
    You can also manually adjust the position of autoplaced elements, or disable autoplace for selected elements.
    Click &quot;Next&quot; to learn more.</source>
        <comment>autoplace-tour</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Autoplace positions most elements according to standard music engraving practice,
    such as by moving tempo markings above other text or by shortening hairpins to avoid dynamics.
    In many cases, this means that no further adjustments will be required at all.</source>
        <comment>autoplace-tour</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>If necessary, you can fine-tune the position of elements by dragging, by using the cursor keys while in Edit mode (double-click),
    or by using the &quot;Offset&quot; fields in the Inspector.
    This allows you to make adjustments while leaving autoplace enabled to continue avoiding collisions.</source>
        <comment>autoplace-tour</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>For larger adjustments, it may be more convenient to disable autoplace for selected elements using the Inspector.
    This will remove them from collision detection and allow you to place them more freely.</source>
        <comment>autoplace-tour</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Welcome to the Timeline, where you can view a high-level reduction of the score for easier navigation.
    Click &quot;Next&quot; to learn more.</source>
        <comment>timeline-tour</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The timeline shows rehearsal marks, changes of tempo, key, and time signature, and other points of interest.
    You can click anywhere to jump to the corresponding location in your score.</source>
        <comment>timeline-tour</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The section below contains a row for each instrument.
    Each box within the row represents a measure for that instrument.
    If the box is highlighted, then there are notes in that measure.
    Boxes with a thin blue outline represent measures that are currently in view.</source>
        <comment>timeline-tour</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>MuseScore supports different types of selections: single, list, and range.
    Click &quot;Next&quot; to learn more.</source>
        <comment>select-tour</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>To make a single selection, click the element you want to select.
    It becomes highlighted to indicate that it is selected.
    You can use the left and right cursor keys to move the selection through the notes and rests of your score.
    Tip: if you press the Alt key (Option on macOS) along with the cursor keys you can move through other elements too,
    and also move up and down from staff to staff.</source>
        <comment>select-tour</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>A list selection is a combination of single selections.
    Press Ctrl (macOS: Cmd) while clicking to add or remove elements to the list selection.
    You can also quickly select similar elements by right-clicking (macOS: Ctrl+clicking) one
    and then choosing one of the &quot;Select&quot; options from the resulting popup menu.</source>
        <comment>select-tour</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>A range selection includes everything from one point in time to another across one or more staves.
    It is indicated by a blue rectangle encompassing the entire range.
    To make a range selection, click the first note, rest, or measure you want to select, then Shift+click the last.
    You can also extend range selections by holding the Shift key while moving the cursor.</source>
        <comment>select-tour</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Another way to make selections is to hold Shift while dragging.
    If your selection includes notes, it will automatically be made as a range selection;
    otherwise it will be made as a list selection.</source>
        <comment>select-tour</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Finally, the Selection Filter (found in the View menu) allows you to exclude elements of a given type from a range selection.</source>
        <comment>select-tour</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>If you have modified a value, you can click the &quot;Reset&quot; button to reset it to the default.
    If the value is controlled by a style setting, you can click the &quot;Set as style&quot; button to set the current value as the new default for the style.
    You can also set style defaults using Format &gt; Style.</source>
        <comment>inspector-tour</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>To create a triplet or other tuplet, select the duration representing the total length of the tuplet, then press Ctrl+number or use Add &gt; Tuplets.</source>
        <comment>note-input</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The File Operations toolbar allows you to create/save/open/print files and undo/redo changes.
    You can also save to your musescore.com account if you go to File &gt; Save Online.
    The controls at the right of this toolbar control the display of your score.</source>
        <comment>welcome</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>That's the end of this tour!
    As you use MuseScore, more tours will pop up to further explain functionality.
    To disable these, deselect &quot;Continue showing tours&quot; before closing this window.
    You can also enable/disable and reset tours in Help &gt; Tours.</source>
        <comment>welcome</comment>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> musescore-3.6.2.tar.gz: MuseScore-3.6.2/share/locale/tours_ko.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ko" version="2.1">
<context>
    <name>TourXML</name>
    <message>
        <source>Welcome to MuseScore! This brief tour will guide you through the MuseScore user interface.</source>
        <comment>welcome</comment>
        <translation>MuseScore에 오신 것을 환영합니다! 간단한 안내를 통해 당신은 MuseScore의 사용자 인터페이스에 적응하실 수 있습니다.</translation>
    </message>
    <message>
        <source>The Playback Controls toolbar allows you to play/pause your score and control various aspects of playback.</source>
        <comment>welcome</comment>
        <translation>재생 컨트롤 툴바는 재생/정지 혹은 다양한 조절을 통해 곡의 재생을 돕습니다.</translation>
    </message>
    <message>
        <source>The Note Input toolbar allows you to enter notes and rests into your score.</source>
        <comment>welcome</comment>
        <translation>음표 입력 툴바는 음표와 쉼표를 악보에 입력할 수 있게 해줍니다.</translation>
    </message>
    <message>
        <source>The Palettes allow you to add most other notation elements to your score.</source>
        <comment>welcome</comment>
        <translation>팔레트는 다른 많은 악상 기호들을 입력할 수 있게 해줍니다.</translation>
    </message>
    <message>
        <source>Each palette contains items that can be added to the score.</source>
        <comment>show-palette</comment>
        <translation>각 팔레트에는 악보에 입력할 수 있는 악상 기호가 있습니다.</translation>
    </message>
    <message>
        <source>Welcome to the Palettes, where you will add various elements to your score. Click &quot;Next&quot; to learn more.</source>
        <comment>show-palette</comment>
        <translation>팔레트에 오신 것을 환영합니다. 팔레트에서는 많은 요소들을 악보에 추가할 수 있습니다. &quot;다음&quot;을 클릭하여 더 알아보기...</translation>
    </message>
    <message>
        <source>To enter notes with different rhythms in the same measure, use multiple voices.
    Each staff can have up to four voices.
    The default is voice 1, and it should be used first for each staff.
    To enter notes into a different voice, click one of these icons.</source>
        <comment>note-input</comment>
        <translation>같은 마디에 서로 다른 리듬을 넣으려면, 여러 개의 성부를 쓰십시오.
 각각의 보표는 최대 4개의 성부를 가질 수 있습니다.
 기본 성부는 제1성부이며, 제1성부는 각 보표에서 가장 먼저 사용되어야 합니다.
 다른 성부를 입력하려면 다음 아이콘 중 하나를 누르십시오.</translation>
    </message>
    <message>
        <source>These are the toolbars.
    The main three are File Operations, Playback Controls, and Note Input.</source>
        <comment>welcome</comment>
        <translation>이것들은 툴바입니다.
 세가지 주요 기능은 파일 작업, 재생 제어, 악보 입력 입니다.</translation>
    </message>
    <message>
        <source>There are different workspaces available with different sets of palettes.
    The &quot;Advanced&quot; workspace contains more items than the &quot;Basic&quot; workspace.</source>
        <comment>show-palette</comment>
        <translation>팔레트의 종류가 다른 여러가지의 작업 환경이 제공됩니다. &quot;전문가&quot; 작업 환경은 &quot;기본&quot; 환경보다 더 많은 아이템을 지원합니다.</translation>
    </message>
    <message>
        <source>To add a palette item to your score, first select an element or range in your score, then double-click on the palette item to add it to the selected elements.
    You can also drag an item from the palette and drop it on a specific element in your score.</source>
        <comment>show-palette</comment>
        <translation>팔레트 아이템을 악보에 삽입하려면, 악보의 항목이나 부분을 클릭한 다음, 팔레트의 항목을 더블클릭하여 해당 항목에 삽입합니다. 이 뿐만 아니라, 팔레트 아이템을 마우스로 끌어놓아 악보에 삽입할  수도 있습니다.</translation>
    </message>
    <message>
        <source>You have toggled multimeasure rests in this score.
    This combines multiple measures of rests into a single multimeasure rest.
    To toggle this setting again, press the shortcut &quot;M&quot;.</source>
        <comment>mmrest</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Welcome to note input, where you will enter notes and rests into your score.
    Click &quot;Next&quot; to learn more.</source>
        <comment>note-input</comment>
        <translation>음표 입력에 오신 것을 환영합니다. 여기서는 음표를 악보에 입력할 수 있습니다. &quot;다음&quot;을 눌러 자세히 알아봅니다.</translation>
    </message>
    <message>
        <source>To enable note input mode, click the &quot;Note input&quot; icon or press the shortcut &quot;N&quot;.</source>
        <comment>note-input</comment>
        <translation>악보 입력 모드를 사용하려면, &quot;악보 입력&quot; 아이콘을 클릭하거나 단축키 &quot;N&quot;을 누르세요.</translation>
    </message>
    <message>
        <source>Select a duration by clicking one of these icons or pressing the shortcuts &quot;1&quot; - &quot;9&quot;.
    To include an augmentation dot, click the appropriate icon or press the shortcut &quot;.&quot;.</source>
        <comment>note-input</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>To enter a rest of the selected duration, press the shortcut &quot;0&quot;, or select this icon then click on the staff.</source>
        <comment>note-input</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>To extend a note by adding a tied note, select the duration to extend by, then press &quot;+&quot; or click this button.</source>
        <comment>note-input</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>MuseScore provides many ways to navigate through your score.
    Click &quot;Next&quot; to learn more.</source>
        <comment>navigate-tour</comment>
        <translation>뮤즈스코어는 악보를 여러 방법으로 변경할 수 있습니다 [다음]을 눌러 더 알아봅니다.
</translation>
    </message>
    <message>
        <source>Additional navigation tools include the Timeline and Navigator, both found in the View menu.</source>
        <comment>navigate-tour</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Welcome to the Inspector, where you can change individual properties for selected elements.
    Click &quot;Next&quot; to learn more.</source>
        <comment>inspector-tour</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Begin by selecting one or more elements in your score, then use the check boxes, spin boxes, dropdown menus, and other controls to change values for the various properties.
    The set of properties available will differ according to the type of selected elements or elements.</source>
        <comment>inspector-tour</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>If you have selected elements of different types, only a few settings common to all elements will be available.
    You can click the &quot;Notes&quot; and other buttons at the bottom of the Inspector to limit the selection to just the elements of the specified type.</source>
        <comment>inspector-tour</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The Inspector allows you to control various properties of the elements in your score.</source>
        <comment>welcome</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Autoplace is a new feature that automatically detects and avoids many types of collisions between elements.
    You can also manually adjust the position of autoplaced elements, or disable autoplace for selected elements.
    Click &quot;Next&quot; to learn more.</source>
        <comment>autoplace-tour</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Autoplace positions most elements according to standard music engraving practice,
    such as by moving tempo markings above other text or by shortening hairpins to avoid dynamics.
    In many cases, this means that no further adjustments will be required at all.</source>
        <comment>autoplace-tour</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>If necessary, you can fine-tune the position of elements by dragging, by using the cursor keys while in Edit mode (double-click),
    or by using the &quot;Offset&quot; fields in the Inspector.
    This allows you to make adjustments while leaving autoplace enabled to continue avoiding collisions.</source>
        <comment>autoplace-tour</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>For larger adjustments, it may be more convenient to disable autoplace for selected elements using the Inspector.
    This will remove them from collision detection and allow you to place them more freely.</source>
        <comment>autoplace-tour</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Welcome to the Timeline, where you can view a high-level reduction of the score for easier navigation.
    Click &quot;Next&quot; to learn more.</source>
        <comment>timeline-tour</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The timeline shows rehearsal marks, changes of tempo, key, and time signature, and other points of interest.
    You can click anywhere to jump to the corresponding location in your score.</source>
        <comment>timeline-tour</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The section below contains a row for each instrument.
    Each box within the row represents a measure for that instrument.
    If the box is highlighted, then there are notes in that measure.
    Boxes with a thin blue outline represent measures that are currently in view.</source>
        <comment>timeline-tour</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>MuseScore supports different types of selections: single, list, and range.
    Click &quot;Next&quot; to learn more.</source>
        <comment>select-tour</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Finally, the Selection Filter (found in the View menu) allows you to exclude elements of a given type from a range selection.</source>
        <comment>select-tour</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>If you have modified a value, you can click the &quot;Reset&quot; button to reset it to the default.
    If the value is controlled by a style setting, you can click the &quot;Set as style&quot; button to set the current value as the new default for the style.
    You can also set style defaults using Format &gt; Style….</source>
        <comment>inspector-tour</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The quickest way to scroll up and down is to use your mouse wheel or equivalent touch gesture (for example, two-finger swipe).
    To scroll horizontally, hold &quot;Shift&quot; while using the mouse wheel or touch gesture.</source>
        <comment>navigate-tour</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The navigation keys on your keyboard such as &quot;PgUp&quot;, &quot;PgDn&quot;, &quot;Home&quot;, and &quot;End&quot; function as in other applications
    to move between pages.
    Keyboards that lack these keys often provide equivalents such as &quot;Fn+Up/Down/Left/Right&quot;.</source>
        <comment>navigate-tour</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You can move the score short distances by clicking an empty area of the page and dragging.
    By the way, you can also select regions by holding &quot;Shift&quot; while dragging.</source>
        <comment>navigate-tour</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>To enter a note of the selected duration, type its letter name or click on the staff.
    Press &quot;Ctrl+Up/Down&quot; (macOS: &quot;Cmd+Up/Down&quot;) to change octave.</source>
        <comment>note-input</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>To add an accidental to a note, press the shortcut &quot;Up&quot; or &quot;Down&quot; to raise or lower its pitch,
    or click one of these icons.</source>
        <comment>note-input</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>To add a note to a chord, press &quot;Shift&quot; while typing its letter name, or click on the staff.</source>
        <comment>note-input</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>To create a triplet or other tuplet, select the duration representing the total length of the tuplet, then press &quot;Ctrl+number&quot; or use Add &gt; Tuplets.</source>
        <comment>note-input</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>To make a single selection, click the element you want to select.
    It becomes highlighted to indicate that it is selected.
    You can use the left and right cursor keys to move the selection through the notes and rests of your score.
    Tip: if you press the &quot;Alt&quot; key (&quot;Option&quot; on macOS) along with the cursor keys you can move through other elements too,
    and also move up and down from staff to staff.</source>
        <comment>select-tour</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>A list selection is a combination of single selections.
    Press &quot;Ctrl&quot; (macOS: &quot;Cmd&quot;) while clicking to add or remove elements to the list selection.
    You can also quickly select similar elements by right-clicking (macOS: &quot;Ctrl&quot;+clicking) one
    and then choosing one of the &quot;Select&quot; options from the resulting popup menu.</source>
        <comment>select-tour</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>A range selection includes everything from one point in time to another across one or more staves.
    It is indicated by a blue rectangle encompassing the entire range.
    To make a range selection, click the first note, rest, or measure you want to select, then &quot;Shift&quot;+click the last.
    You can also extend range selections by holding the &quot;Shift&quot; key while moving the cursor.</source>
        <comment>select-tour</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Another way to make selections is to hold &quot;Shift&quot; while dragging.
    If your selection includes notes, it will automatically be made as a range selection;
    otherwise it will be made as a list selection.</source>
        <comment>select-tour</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Most elements on the lines palette span a range from a start element to an end element.

    To edit its range, double-click the line (which automatically selects its end handle) and:

    - Press &quot;Shift+Right&quot; to move that handle forward.

    - Press &quot;Shift+Left&quot; to move that handle backward.</source>
        <comment>spanner-drop-apply</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Alternatively, first selecting a range of elements in the score and then double-clicking a line element in the palette will add that new element across the selected range.</source>
        <comment>spanner-drop-apply</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>This is the score view, where you can view and edit your score.
    Use your mouse wheel or touchpad to scroll (with &quot;Shift&quot; to scroll horizontally).
    If you have multiple scores open, you can switch between them using tabs at the top of your score view.</source>
        <comment>welcome</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The File Operations toolbar allows you to create/save/open/print files and undo/redo changes.
    You can also save to your musescore.com account if you go to File &gt; Save Online.
    The controls at the right of this toolbar control the display of your score.</source>
        <comment>welcome</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The main menu contains most other commands.
    In addition, many commands can be accessed via keyboard shortcuts or by right-clicking (macOS: &quot;Ctrl&quot;+clicking) within the score view.</source>
        <comment>welcome</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>That's the end of this tour!
    As you use MuseScore, more tours will pop up to further explain functionality.
    To disable these, deselect &quot;Continue showing tours&quot; before closing this window.
    You can also enable/disable and reset tours in Help &gt; Tours.</source>
        <comment>welcome</comment>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
